[![Build Status](https://travis-ci.org/waderoberts123/Hydrostats.svg?branch=master)](https://travis-ci.org/waderoberts123/Hydrostats)
[![codecov](https://codecov.io/gh/waderoberts123/Hydrostats/branch/master/graph/badge.svg)](https://codecov.io/gh/waderoberts123/Hydrostats)

Tools for use in comparison studies, specifically for use in the field of hydrology

- **Documentation:** https://waderoberts123.github.io/Hydrostats/
- **Source:** https://github.com/waderoberts123/Hydrostats
- **Bug reports:** https://github.com/waderoberts123/Hydrostats/issues

Hydrostats provides:

- Preprocessing Tools
- Visualization Tools
- Access to over 60 error metrics through the [HydroErr package](https://github.com/waderoberts123/HydroErr) dependency
- A library of relevant metrics to measure forecast skill

[![Powered by BYU Hydroinformatics](https://img.shields.io/badge/powered%20by-BYU%20HydroInformatics-blue.svg)](http://worldwater.byu.edu/)
